Struct massa_event_cache::event_cache::EventCache
source · pub(crate) struct EventCache {Show 13 fields
db: DB,
entry_count: usize,
max_entry_count: usize,
snip_amount: usize,
event_ser: SCOutputEventSerializer,
event_deser: SCOutputEventDeserializer,
key_builder: DbKeyBuilder,
first_slot: Slot,
last_slot: Slot,
thread_count: u8,
max_events_per_operation: u64,
max_operations_per_block: u64,
max_events_per_query: usize,
}Expand description
Disk based event cache db (rocksdb based)
Fields
db: DBRocksDB database
entry_count: usizeHow many entries are in the db. Count is initialized at creation time by iterating over all the entries in the db then it is maintained in memory
max_entry_count: usizeMaximum number of entries we want to keep in the db.
When this maximum is reached snip_amount entries are removed
snip_amount: usizeHow many entries are removed when entry_count reaches max_entry_count
event_ser: SCOutputEventSerializerEvent serializer
event_deser: SCOutputEventDeserializerEvent deserializer
key_builder: DbKeyBuilderKey builder
first_slot: SlotFirst event slot in db
last_slot: SlotLast event slot in db
thread_count: u8Thread count
max_events_per_operation: u64Maximum number of events per operation
max_operations_per_block: u64Maximum number of operations per block
max_events_per_query: usizeMax number of events returned by a query
Implementations
sourceimpl EventCache
impl EventCache
sourcepub fn new(
path: &Path,
max_entry_count: usize,
snip_amount: usize,
thread_count: u8,
max_recursive_call_depth: u16,
max_event_data_length: u64,
max_events_per_operation: u64,
max_operations_per_block: u64,
max_events_per_query: usize,
) -> Self
pub fn new( path: &Path, max_entry_count: usize, snip_amount: usize, thread_count: u8, max_recursive_call_depth: u16, max_event_data_length: u64, max_events_per_operation: u64, max_operations_per_block: u64, max_events_per_query: usize, ) -> Self
Create a new EventCache
sourcefn insert_into_batch(&mut self, event: SCOutputEvent, batch: &mut WriteBatch)
fn insert_into_batch(&mut self, event: SCOutputEvent, batch: &mut WriteBatch)
From an event add keys & values into a rocksdb batch
sourcepub fn insert(&mut self, event: SCOutputEvent)
pub fn insert(&mut self, event: SCOutputEvent)
Insert a new event in the cache
sourcepub fn insert_multi_it(
&mut self,
events: impl ExactSizeIterator<Item = SCOutputEvent> + Clone,
)
pub fn insert_multi_it( &mut self, events: impl ExactSizeIterator<Item = SCOutputEvent> + Clone, )
Insert new events in the cache
sourcepub(crate) fn get_filtered_sc_output_events(
&self,
filter: &EventFilter,
) -> (Vec<u64>, Vec<SCOutputEvent>)
pub(crate) fn get_filtered_sc_output_events( &self, filter: &EventFilter, ) -> (Vec<u64>, Vec<SCOutputEvent>)
Get events filtered by the given argument
fn filter_for( &self, indent: &KeyIndent, filter_item: &FilterItem, result: &mut BTreeSet<Vec<u8>>, seen: Option<&BTreeSet<Vec<u8>>>, ) -> u64
sourcefn filter_item_estimate_count(
&self,
key_indent: &KeyIndent,
filter_item: &FilterItem,
) -> Result<u64, ModelsError>
fn filter_item_estimate_count( &self, key_indent: &KeyIndent, filter_item: &FilterItem, ) -> Result<u64, ModelsError>
Estimate for a given KeyIndent & FilterItem the number of row to iterate